@@ -36,6 +36,7 @@ def mkqueue(pipeline, head):
 	return pipeparts.mkqueue(pipeline, head, max_size_time = 0, max_size_buffers = 0, max_size_bytes = 0)
 	
 def mkaudiorate(pipeline, head):
+	#return pipeparts.mkqueue(pipeline, head)
 	return pipeparts.mkaudiorate(pipeline, head, skip_to_first = True, silent = False)
 
 def mkreblock(pipeline, head):
@@ -78,7 +79,7 @@ def caps_and_progress_and_upsample(pipeline, head, caps, progress_name, new_caps
 def resample(pipeline, head, caps):
 	head = pipeparts.mkresample(pipeline, head, quality = 9)
 	head = pipeparts.mkcapsfilter(pipeline, head, caps)
-	head = mkaudiorate(pipeline, head)
+	#head = mkaudiorate(pipeline, head)
 	head = mkreblock(pipeline, head)
 	return head
 
@@ -91,7 +92,7 @@ def mkmultiplier(pipeline, srcs, caps, sync = True):
 	return elem
 
 def mkinterleave(pipeline, srcs, caps):
-	elem = pipeparts.mkgeneric(pipeline, None, "lal_interleave")
+	elem = pipeparts.mkgeneric(pipeline, None, "lal_interleave", sync = True)
 	if srcs is not None:
 		for src in srcs:
 			pipeparts.mkcapsfilter(pipeline, src, caps).link(elem)
@@ -111,13 +112,11 @@ def list_srcs(pipeline, *args):
 		out.append(mkqueue(pipeline, src))
 	return tuple(out)
 
-def average_calib_factors(pipeline, head, var, expected, averaging_time, caps, default, statevector, td):
-	averaging_rate = 16
-	N = averaging_time * averaging_rate
+def average_calib_factors(pipeline, head, var, expected, N, caps, td, hold_time):
 	head = pipeparts.mkaudioconvert(pipeline, head)
 	head = pipeparts.mkcapsfilter(pipeline, head, caps)
-	head = pipeparts.mkgeneric(pipeline, head, "lal_check_calib_factors", min = expected - var, max = expected + var, default = expected)
-	head = resample(pipeline, head, "audio/x-raw-float, rate=%d" % averaging_rate)
+	head = pipeparts.mkgeneric(pipeline, head, "lal_check_calib_factors", variance = var, default = expected, wait_time_to_new_expected = hold_time)
+	head = mkaudiorate(pipeline, head)
 	head = pipeparts.mkfirbank(pipeline, head, fir_matrix = [numpy.ones(N)/N], time_domain = td)
 	head = resample(pipeline, head, caps)
 	return head
@@ -153,13 +152,11 @@ def demodulate(pipeline, head, sr, freq, orig_caps, new_caps, integration_sample
 	sin = pipeparts.mkgeneric(pipeline, mkqueue(pipeline, headtee), "lal_numpy_fx_transform", expression = "-1.0 * %f * sin(2.0 * 3.1415926535897931 * %f * t)" % (deltat, freq))
 
 	headR = mkmultiplier(pipeline, (mkqueue(pipeline, headtee), cos), orig_caps)
-	headR = pipeparts.mkresample(pipeline, headR, quality=9)
-	headR = pipeparts.mkcapsfilter(pipeline, headR, new_caps)
+	headR = resample(pipeline, headR, new_caps)
 	headR = pipeparts.mkfirbank(pipeline, headR, fir_matrix=[numpy.hanning(integration_samples+1)], time_domain = td)
 
 	headI = mkmultiplier(pipeline, (mkqueue(pipeline, headtee), sin), orig_caps)
-	headI = pipeparts.mkresample(pipeline, headI, quality=9)
-	headI = pipeparts.mkcapsfilter(pipeline, headI, new_caps)
+	headI = resample(pipeline, headI, new_caps)
 	headI = pipeparts.mkfirbank(pipeline, headI, fir_matrix=[numpy.hanning(integration_samples+1)], time_domain = td)
 
 	return headR, headI
